@@ -31,7 +31,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  * strverscmp(3) is a GNU extension. In most supporting C libraries it
  * requires _GNU_SOURCE to be defined.
  */
-#ifdef HAVE_VERSCMP
+#ifdef HAVE_STRVERSCMP
 #define _GNU_SOURCE
 #endif
 
@@ -182,6 +182,9 @@ gib_list *feh_list_jump(gib_list * root, gib_list * l, int direction, int num);
 #ifdef HAVE_INOTIFY
 void feh_event_handle_inotify(void);
 #endif
+#ifndef HAVE_STRVERSCMP
+int strverscmp(const char *l0, const char *r0);
+#endif
 
 /* Imlib stuff */
 extern Display *disp;
