@@ -943,8 +943,8 @@ static void show_version(void)
 		"stat64 "
 #endif
 
-#ifdef HAVE_VERSCMP
-		"verscmp "
+#ifdef HAVE_STRVERSCMP
+         "verscmp "
 #endif
 
 #ifdef HAVE_LIBXINERAMA
